@@ -18,8 +18,8 @@ import scipy
 import scipy.signal
 from numpy.fft import ifftshift, irfftn, rfftn
 from scipy.fft import next_fast_len
+from scipy.ndimage import fourier_gaussian
 from scipy.ndimage._ni_support import _normalize_sequence
-from scipy.ndimage.fourier import fourier_gaussian
 
 logger = logging.getLogger(__name__)
 
@@ -178,7 +178,7 @@ def radial_profile(data, center=None, binsize=1.0):
         # imaginary parts and return the complex sum.
         real_prof, real_std = radial_profile(np.real(data), center, binsize)
         imag_prof, imag_std = radial_profile(np.imag(data), center, binsize)
-        return real_prof + imag_prof * 1j, np.sqrt(real_std ** 2 + imag_std ** 2)
+        return real_prof + imag_prof * 1j, np.sqrt(real_std**2 + imag_std**2)
         # or do mag and phase
         # mag_prof, mag_std = radial_profile(np.abs(data), center, binsize)
         # phase_prof, phase_std = radial_profile(np.angle(data), center, binsize)
@@ -193,13 +193,13 @@ def radial_profile(data, center=None, binsize=1.0):
         center = np.asarray(center)
     # calculate the radius from center
     idx2 = idx - center[(Ellipsis,) + (np.newaxis,) * (data.ndim)]
-    r = np.sqrt(np.sum([i ** 2 for i in idx2], 0))
+    r = np.sqrt(np.sum([i**2 for i in idx2], 0))
     # convert to int
     r = np.round(r / binsize).astype(int)
     # sum the values at equal r
     tbin = np.bincount(r.ravel(), data.ravel())
     # sum the squares at equal r
-    tbin2 = np.bincount(r.ravel(), (data ** 2).ravel())
+    tbin2 = np.bincount(r.ravel(), (data**2).ravel())
     # find how many equal r's there are
     nr = np.bincount(r.ravel())
     # calculate the radial mean
@@ -207,7 +207,7 @@ def radial_profile(data, center=None, binsize=1.0):
     # have NaN for binsize != 1
     radial_mean = tbin / nr
     # calculate the radial std
-    radial_std = np.sqrt(tbin2 / nr - radial_mean ** 2)
+    radial_std = np.sqrt(tbin2 / nr - radial_mean**2)
     # return them
     return radial_mean, radial_std
 
@@ -390,7 +390,7 @@ def fftconvolve_fast(data, kernel, **kwargs):
     """FFT convolution, a faster version than scipy.
 
     In this case the kernel ifftshifted before FFT but the data is not.
-    This can be done because the effect of fourier convolution is to 
+    This can be done because the effect of fourier convolution is to
     "wrap" around the data edges so whether we ifftshift before FFT
     and then fftshift after it makes no difference so we can skip the
     step entirely.
@@ -467,10 +467,10 @@ def anscombe_inv(data):
 
     https://en.wikipedia.org/wiki/Anscombe_transform
     """
-    part0 = 1 / 4 * data ** 2
+    part0 = 1 / 4 * data**2
     part1 = 1 / 4 * np.sqrt(3 / 2) / data
-    part2 = -11 / 8 / (data ** 2)
-    part3 = 5 / 8 * np.sqrt(3 / 2) / (data ** 3)
+    part2 = -11 / 8 / (data**2)
+    part3 = 5 / 8 * np.sqrt(3 / 2) / (data**3)
     return part0 + part1 + part2 + part3 - 1 / 8
 
 
@@ -512,7 +512,7 @@ def fft_gaussian_filter(img, sigma):
 
 def find_prime_facs(n):
     """Find the prime factors of n.
-    
+
     Example
     -------
     >>> find_prime_facs(10)
@@ -572,9 +572,21 @@ def latex_format_e(num, pre=2):
     return "{} \\times 10^{{{}}}".format(fp, int(xp))
 
 
+def localize_peak_1d(data):
+    """Small utility function to localize a peak center."""
+    # pull center location
+    center = len(data) // 2
+    # fit along lines, consider the center to be 0
+    x = np.arange(len(data)) - center
+    fit = np.polyfit(x, data, 2)
+    # calculate center of each parabola
+    x0 = -fit[1] / (2 * fit[0])
+    return x0
+
+
 def localize_peak(data):
     """Small utility function to localize a peak center.
-    
+
     Assumes passed data has peak at center and that data.shape is odd and symmetric.
     Then fits a parabola through each line passing through the center. This is optimized
     for FFT data which has a non-circularly symmetric shaped peaks.
@@ -623,7 +635,7 @@ def edf(stack):
 
 def plane_fit(X, Y, Z):
     """Fit a plane to data.
-    
+
     Parameters
     ----------
     X : np.ndarray
@@ -657,7 +669,7 @@ def find_normal(X, Y, Z):
     normal = np.array((-C[0], -C[1], 1))
 
     # return normalized normal vector
-    return normal / np.sqrt((normal ** 2).sum())
+    return normal / np.sqrt((normal**2).sum())
 
 
 def rot_matrix(source, target):
@@ -683,7 +695,11 @@ def calc_angles(mat_b):
 
 
 def fit_quadratic(x: np.ndarray, y: np.ndarray, z: np.ndarray) -> np.ndarray:
-    """Fit quadratic to point data."""
+    """Fit quadratic to point data.
+
+    Parameters are:
+    C[0] * X ** 2 + C[1] * Y ** 2 + C[2] * X + C[3] * Y + C[4] * X * Y + C[5]
+    """
     # assume data is on a regularly spaced grid
 
     # flatten everything, just to be sure
@@ -702,11 +718,27 @@ def fit_quadratic(x: np.ndarray, y: np.ndarray, z: np.ndarray) -> np.ndarray:
 
 def find_center(x: np.ndarray, y: np.ndarray, z: np.ndarray) -> np.ndarray:
     """Find center of parabola.
-    
+
     https://en.wikipedia.org/wiki/Quadratic_function#Minimum/maximum
+
+    Parameters
+    ----------
+    x, y, z : np.ndarrays
+        The x, y, and z coordinates of the data (assumes that x and y
+        are independent variables and z is dependent)
+
+    Returns
+    -------
+    (x_m, y_m) : floats
+        The center as determined by a parabolic fit
     """
     # get fit coefs
-    aa, bb, cc, dd, ee, _ = fit_quadratic(x, y, z)
+    quad_coefs = fit_quadratic(x, y, z)
+    return find_center_quad_coefs(quad_coefs)
+
+
+def find_center_quad_coefs(quad_coefs):
+    aa, bb, cc, dd, ee, _ = quad_coefs
     denom = 4 * aa * bb - ee * ee
 
     # check if an extreme point is found
@@ -716,7 +748,7 @@ def find_center(x: np.ndarray, y: np.ndarray, z: np.ndarray) -> np.ndarray:
     x_m = -(2 * bb * cc - dd * ee) / denom
     y_m = -(2 * aa * dd - cc * ee) / denom
 
-    return (y_m, x_m)
+    return (x_m, y_m)
 
 
 class EasyTimer(object):
@@ -743,3 +775,47 @@ class EasyTimer(object):
             elapsed_str = f"{elapsed:.1f} s"
         print(f"{self.msg}: Elapsed time {elapsed_str}")
         return False
+
+
+def split_img(img, sides):
+    """Split an image (or volume) into tiles.
+
+    taken from https://github.com/david-hoffman/scripts/blob/master/simrecon_utils.py
+    """
+    # Testing input
+    divisors = img.shape // np.array(sides)
+    # Error checking
+    for dim, side, divisor in zip(img.shape, sides, divisors):
+        assert side == dim / divisor, "Side {}, not equal to {}/{}".format(side, dim, divisor)
+
+    # reshape array so that it's a tiled image
+    img_s0 = img.reshape(divisors[0], sides[0], divisors[1], sides[1])
+    # roll one axis so that the tile's y, x coordinates are next to each other
+    img_s1 = np.rollaxis(img_s0, -3, -1)
+    # combine the tile's y, x coordinates into one axis.
+    return img_s1.reshape(np.product(divisors), sides[0], sides[1])
+
+
+def crop_image_for_split(img, sides):
+    """Take an image and a side and crop it apropriately to ensure that split_img will work."""
+    # get dimensions of image
+    ny, nx = img.shape
+    # find how many pixels to be shaved
+    ry, rx = ny % sides[0], nx % sides[1]
+    # find left amount
+    ryl, rxl = ry // 2, rx // 2
+    # find right amount
+    ryr, rxr = ry - ryl, rx - rxl
+
+    return img[ryl : ny - ryr, rxl : nx - rxr]
+
+
+def combine_img(stack):
+    """Combine tiled stack."""
+    length = len(stack)
+    ny = int(np.sqrt(length))
+
+    assert length % ny == 0
+    assert length // ny == ny
+
+    return stack.reshape(ny, ny)
